==> kdepim-addons-17.03.90.tar.xz: kdepim-addons-17.03.90/kmail/editorplugins/zoomtext/zoomtextplugineditor.cpp <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "zoomtextplugineditor.h"
#include "zoomtextplugineditorinterface.h"
#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(ZoomTextPluginEditorFactory, "kmail_zoomtexteditorplugin.json", registerPlugin<ZoomTextPluginEditor>();)

ZoomTextPluginEditor::ZoomTextPluginEditor(QObject *parent, const QList<QVariant> &)
    : MessageComposer::PluginEditor(parent)
{

}

ZoomTextPluginEditor::~ZoomTextPluginEditor()
{

}

MessageComposer::PluginEditorInterface *ZoomTextPluginEditor::createInterface(KActionCollection *ac, QObject *parent)
{
    ZoomTextPluginEditorInterface *interface = new ZoomTextPluginEditorInterface(parent);
    interface->createAction(ac);
    return interface;
}

bool ZoomTextPluginEditor::hasPopupMenuSupport() const
{
    return false;
}

#include "zoomtextplugineditor.moc"

==> kdepim-addons_17.12.3.orig.tar.xz: kdepim-addons-17.12.3/kmail/editorplugins/zoomtext/zoomtextplugineditor.cpp <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "zoomtextplugineditor.h"
#include "zoomtextplugineditorinterface.h"
#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(ZoomTextPluginEditorFactory, "kmail_zoomtexteditorplugin.json", registerPlugin<ZoomTextPluginEditor>();
                           )

ZoomTextPluginEditor::ZoomTextPluginEditor(QObject *parent, const QList<QVariant> &)
    : MessageComposer::PluginEditor(parent)
{
}

ZoomTextPluginEditor::~ZoomTextPluginEditor()
{
}

MessageComposer::PluginEditorInterface *ZoomTextPluginEditor::createInterface(KActionCollection *ac, QObject *parent)
{
    ZoomTextPluginEditorInterface *interface = new ZoomTextPluginEditorInterface(parent);
    interface->createAction(ac);
    return interface;
}

bool ZoomTextPluginEditor::hasPopupMenuSupport() const
{
    return false;
}

#include "zoomtextplugineditor.moc"
